@@ -2,6 +2,7 @@ import os
 import shutil
 import requests
 import git
+import re
 
 from columnar import columnar
 from pathlib import Path
@@ -52,13 +53,16 @@ def _create_local_version_path(
     )
 
     shutil.copy(notebook_to_copy, new_notebook)
+
+    re_sub_version_name = r"([a-zA-Z0-9\-\_]+\/[a-zA-Z0-9\-\_]+\/)[a-zA-Z\-\_]+"
     with open(new_notebook) as f_in:
-        _text = f_in.read().replace(
-            previous_model_version["id"], new_model_version["id"]
+        notebook_contents = f_in.read()
+        new_notebook_contents = re.sub(
+            re_sub_version_name, r"\1" + new_model_version["name"], notebook_contents
         )
 
     with open(new_notebook, "w") as f_out:
-        f_out.write(_text)
+        f_out.write(new_notebook_contents)
 
     # copy handler and test event
     shutil.copytree(
