@@ -8,7 +8,7 @@ from slai_cli import log
 
 
 def list_profiles():
-    headers = ["name", "client_id", "client_secret", "aws_profile"]
+    headers = ["name", "client_id", "client_secret"]
 
     credentials_path = f"{Path.home()}/.slai"
     try:
@@ -25,7 +25,6 @@ def list_profiles():
             profile_name,
             credentials[profile_name]["client_id"],
             credentials[profile_name]["client_secret"],
-            credentials[profile_name]["aws_profile"],
         ]
         for profile_name in credentials.keys()
     ]
